@@ -18,7 +18,7 @@ double logSumExp(const arma::vec& x) {
   }
   LDOUBLE cumsum = 0.0;
   for (unsigned int i = 0; i < x.n_elem; i++) {
-    if ((i != maxi) & (x(i) > -arma::datum::inf)) {
+    if ((i != maxi) && (x(i) > -arma::datum::inf)) {
       cumsum += EXPL(x(i) - maxv);
     }
   }
